@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.0902';
+our $VERSION = '0.1000';
 
 use strict;
 use warnings;
@@ -20,6 +20,7 @@ our @EXPORT = qw(
     set_time_sig
     setup_score
     dura_size
+    ticks
 );
 
 use constant TICKS => 96;
@@ -215,6 +216,12 @@ sub dura_size {
     return $size;
 }
 
+
+sub ticks {
+    my ($score) = @_;
+    return ${ $score->{Tempo} };
+}
+
 1;
 
 __END__
@@ -229,7 +236,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.0902
+version 0.1000
 
 =head1 SYNOPSIS
 
@@ -348,6 +355,12 @@ value (e.g. C<hn>, C<ten>) or number of ticks (if given as C<d###>).
 If a B<ppqn> value is not given, we use the MIDI::Simple value of
 C<96> ticks.
 
+=head2 ticks
+
+  $ticks = ticks($score);
+
+Return the B<score> ticks.
+
 =head1 SEE ALSO
 
 The F<t/01-functions.t> test file in this distribution
@@ -364,7 +377,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Gene Boggs.
+This software is copyright (c) 2022 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
